@@ -63,9 +63,13 @@ class TextTaggerCore(widgets.DOMWidget):
         This is a front-end widget that displays its 'text' attribute. When a
         sub-string is highlighted, it will snap to the word boundaries, and
         mark it as a span of type `widget.selected_class`. All spans that are
-        highlighted are available under `widget.entity_spans`, which is
+        highlighted are available under `widget.entity_spans`, which is also
         assignable.
 
+        Select the type of entity to tag by clicking its corresponding button,
+        or by using the hotkeys 1-0. Hotkeys are mapped to entities in the
+        order in which they appear on screen.
+
         Parameters
         ----------
         text : str, optional
@@ -183,8 +187,7 @@ class TextTagger(LabellingWidgetMixin, widgets.VBox):
 
     def _handle_keystroke(self, event):
         super()._handle_keystroke(event)
-        for i, option in enumerate(self.class_selector.options):
-            if event["key"] == f"{(i + 1) % 10}":
+        keys = [str(i) for i in range(1, 10)] + ["0"]
+        for key, option in zip(keys, self.class_selector.options):
+            if event.get("key") == key:
                 self.class_selector.value = option
-            if i == 10:
-                break  # pragma: no cover
